@@ -24,12 +24,15 @@
 #include <glib-object.h>
 
 #include <time.h>
-#include <pthread.h>
+
+#include <ags/libags.h>
 
 #include <ags/audio/ags_port.h>
 
 #include <ags/audio/osc/controller/ags_osc_controller.h>
 
+G_BEGIN_DECLS
+
 #define AGS_TYPE_OSC_METER_CONTROLLER                (ags_osc_meter_controller_get_type())
 #define AGS_OSC_METER_CONTROLLER(obj)                (G_TYPE_CHECK_INSTANCE_CAST((obj), AGS_TYPE_OSC_METER_CONTROLLER, AgsOscMeterController))
 #define AGS_OSC_METER_CONTROLLER_CLASS(class)        (G_TYPE_CHECK_CLASS_CAST(class, AGS_TYPE_OSC_METER_CONTROLLER, AgsOscMeterControllerClass))
@@ -56,10 +59,6 @@ struct _AgsOscMeterController
   AgsOscController osc_controller;
 
   guint flags;
-
-  struct timespec *monitor_timeout;
-  
-  pthread_t *monitor_thread;
   
   GList *monitor;
 };
@@ -73,7 +72,7 @@ struct _AgsOscMeterControllerClass
 	
   gpointer (*monitor_meter)(AgsOscMeterController *osc_meter_controller,
 			    AgsOscConnection *osc_connection,
-			    unsigned char *message, guint message_size);
+			    guchar *message, guint message_size);
 };
 
 struct _AgsOscMeterControllerMonitor
@@ -117,8 +116,10 @@ void ags_osc_meter_controller_stop_monitor(AgsOscMeterController *osc_meter_cont
 
 gpointer ags_osc_meter_controller_monitor_meter(AgsOscMeterController *osc_meter_controller,
 						AgsOscConnection *osc_connection,
-						unsigned char *message, guint message_size);
+						guchar *message, guint message_size);
 
 AgsOscMeterController* ags_osc_meter_controller_new();
 
+G_END_DECLS
+
 #endif /*__AGS_OSC_METER_CONTROLLER_H__*/
